@@ -1,7 +1,7 @@
 /* policy.h
    Configuration file for policy decisions.  To be edited on site.
 
-   Copyright (C) 1991, 1992, 1993 Ian Lance Taylor
+   Copyright (C) 1991, 1992, 1993, 1994, 1995 Ian Lance Taylor
 
    This file is part of the Taylor UUCP package.
 
@@ -17,10 +17,10 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
    The author of the program may be contacted at ian@airs.com or
-   c/o Cygnus Support, Building 200, 1 Kendall Square, Cambridge, MA 02139.
+   c/o Cygnus Support, 48 Grove Street, Somerville, MA 02144.
    */
 
 /* This header file contains macro definitions which must be set by
@@ -72,10 +72,10 @@
    figure out what's happening if something goes wrong.  */
 
 #if HAVE_BSD_TTY + HAVE_SYSV_TERMIO + HAVE_POSIX_TERMIOS == 0
-#ifdef __QNX__
+#if HAVE_TERMIOS_H
 #undef HAVE_POSIX_TERMIOS
 #define HAVE_POSIX_TERMIOS 1
-#else /* ! defined (__QNX__) */
+#else /* ! HAVE_TERMIOS_H */
 #if HAVE_CBREAK
 #undef HAVE_BSD_TTY
 #define HAVE_BSD_TTY 1
@@ -83,7 +83,7 @@
 #undef HAVE_SYSV_TERMIO
 #define HAVE_SYSV_TERMIO 1
 #endif /* ! HAVE_CBREAK */
-#endif /* ! defined (__QNX__) */
+#endif /* ! HAVE_TERMIOS_H */
 #endif /* HAVE_BSD_TTY + HAVE_SYSV_TERMIO + HAVE_POSIX_TERMIOS == 0 */
 
 /* On some systems a write to a serial port will block even if the
@@ -205,16 +205,22 @@
    other than the uucp user uses it.  */
 #define HAVE_SAVED_SETUID 1
 
-/* On some systems, such as the DG Aviion and, possibly, the RS/6000,
-   the setreuid function is broken.  It should be possible to use
-   setreuid to swap the real and effective user ID's, but on some
-   systems it will not change the real user ID (I believe this is due
-   to a misreading of the POSIX standard).  On such a system you must
-   set HAVE_BROKEN_SETREUID to 1; if you do not, you will get error
-   messages from setreuid.  Systems on which setreuid exists but is
-   broken pretty much always have saved setuid.  */
+/* On some systems, such as 4.4BSD-Lite, NetBSD, the DG Aviion and,
+   possibly, the RS/6000, the setreuid function is broken.  It should
+   be possible to use setreuid to swap the real and effective user
+   ID's, but on some systems it will not change the real user ID (I
+   believe this is due to a misreading of the POSIX standard).  On
+   such a system you must set HAVE_BROKEN_SETREUID to 1; if you do
+   not, you will get error messages from setreuid.  Systems on which
+   setreuid exists but is broken pretty much always have saved setuid.  */
 #define HAVE_BROKEN_SETREUID 0
 
+/* On a few systems, such as NextStep 3.3, the POSIX macro F_SETLKW is
+   defined, but does not work.  On such systems, you must set
+   HAVE_BROKEN_SETLKW to 1.  If you do not, uux will hang, or log
+   peculiar error messages, every time it is run.  */
+#define HAVE_BROKEN_SETLKW 0
+
 /* On the 3B2, and possibly other systems, nap takes an argument in
    hundredths of a second rather than milliseconds.  I don't know of
    any way to test for this.  Set HAVE_HUNDREDTHS_NAP to 1 if this is
@@ -296,6 +302,7 @@
 /* #define LOCKDIR "/usr/spool/locks" */
 /* #define LOCKDIR "/usr/spool/uucp/LCK" */
 /* #define LOCKDIR "/var/spool/lock" */
+#define LOCKDIR "/var/lock"
 
 /* You must also specify the format of the lock files by setting
    exactly one of the following macros to 1.  Check an existing lock
@@ -342,7 +349,7 @@
    The format for QNX lock files was made up just for Taylor UUCP.
    QNX doesn't come with a version of UUCP.  */
 #define HAVE_V2_LOCKFILES 0
-#define HAVE_HDB_LOCKFILES 0
+#define HAVE_HDB_LOCKFILES 1
 #define HAVE_SCO_LOCKFILES 0
 #define HAVE_SVR4_LOCKFILES 0
 #define HAVE_SEQUENT_LOCKFILES 0
@@ -459,8 +466,8 @@
    When looking something up (a system, a port, etc.) the new style
    configuration files will be read first, followed by the V2
    configuration files, followed by the HDB configuration files.  */
-#define HAVE_V2_CONFIG 0
-#define HAVE_HDB_CONFIG 0
+#define HAVE_V2_CONFIG 1
+#define HAVE_HDB_CONFIG 1
 
 /* Exactly one of the following macros must be set to 1.  The exact
    format of the spool directories is explained in unix/spool.c.
@@ -623,24 +630,33 @@
    permitted. */
 #define ALLOW_FILENAME_ARGUMENTS 1
 
+/* If you set FSYNC_ON_CLOSE to 1, all output files will be forced out
+   to disk using the fsync system call when they are closed.  This can
+   be useful if you can not afford to lose people's mail if the system
+   crashes.  However, not all systems have the fsync call, and it is
+   always less efficient to use it.  Note that some versions of SCO
+   Unix, and possibly other systems, make fsync a synonym for sync,
+   which is extremely inefficient.  */
+#define FSYNC_ON_CLOSE 0
+
 #if HAVE_TAYLOR_LOGGING
 
 /* The default log file when using HAVE_TAYLOR_LOGGING.  When using
    HAVE_TAYLOR_CONFIG, this may be overridden by the ``logfile''
    command in the configuration file.  */
-#define LOGFILE "/usr/spool/uucp/Log"
+#define LOGFILE "/var/log/uucp/Log"
 /* #define LOGFILE "/var/spool/uucp/Log" */
 
 /* The default statistics file when using HAVE_TAYLOR_LOGGING.  When
    using HAVE_TAYLOR_CONFIG, this may be overridden by the
    ``statfile'' command in the configuration file.  */
-#define STATFILE "/usr/spool/uucp/Stats"
+#define STATFILE "/var/log/uucp/Stats"
 /* #define STATFILE "/var/spool/uucp/Stats" */
 
 /* The default debugging file when using HAVE_TAYLOR_LOGGING.  When
    using HAVE_TAYLOR_CONFIG, this may be overridden by the
    ``debugfile'' command in the configuration file.  */
-#define DEBUGFILE "/usr/spool/uucp/Debug"
+#define DEBUGFILE "/var/log/uucp/Debug"
 /* #define DEBUGFILE "/var/spool/uucp/Debug" */
 
 #endif /* HAVE_TAYLOR_LOGGING */
